@@ -46,7 +46,8 @@ class QtSassThemeGetter:
 
     def getThemeFiles(self, theme: str = 'dark', output_path=os.getcwd()):
         cur_dir = os.path.dirname(__file__)
-        ico_dirname = os.path.join(cur_dir, os.path.join('ico', theme))
+        theme_prefix = theme.split('_')[0]
+        ico_dirname = os.path.join(cur_dir, os.path.join('ico', theme_prefix))
         sass_dirname = os.path.join(cur_dir, 'sass')
         var_dirname = os.path.join(cur_dir, os.path.join('var', theme))
         os.chdir(output_path)
@@ -67,18 +68,17 @@ class QtSassThemeGetter:
         shutil.copytree(var_dirname, 'var')
 
         ico_filename = 'ico/_icons.scss'
-
         self.__setIconPath(ico_filename, output_dirname)
 
+    def setThemeFiles(self, main_window: QWidget, input_path='res', exclude_type_lst: list = []):
         qtsass.compile_dirname('sass', '.')
 
+        ico_filename = 'ico/_icons.scss'
         os.remove(ico_filename)
         shutil.rmtree('sass')
         shutil.rmtree('var')
 
         os.chdir('../')
-
-    def setThemeFiles(self, main_window: QWidget, input_path='res', exclude_type_lst: list = []):
         if os.path.isdir(input_path):
             f_lst = ['theme.css', 'main_widget.css', 'icon_button.css', 'icon_text_button.css', 'menu_bar.css']
             input_path = os.path.join(os.getcwd(), input_path)
